@@ -34,8 +34,8 @@ class VpncAdvancedWidget : public QDialog
 {
     Q_OBJECT
 public:
-    explicit VpncAdvancedWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0);
-    ~VpncAdvancedWidget();
+    explicit VpncAdvancedWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
+    ~VpncAdvancedWidget() override;
 
     NMStringMap setting() const;
     void loadConfig(const NetworkManager::VpnSetting::Ptr &setting);
